 /*****************************************************************************
 *   Copyright (C) 2004 by Andrew de Quincey                                  *
 *   adq@lidskialf.net                                                        *
 *   Copyright (C) 2005 by Michael Schulze                                    *
 *   mike.s@genion.de                                                         *
 *                                                                            *
 *  The code contained in this file is free software; you can redistribute    *
 *  it and/or modify it under the terms of the GNU Lesser General Public      *
 *  License as published by the Free Software Foundation; either version      *
 *  2.1 of the License, or (at your option) any later version.                *
 *                                                                            *
 *  This file is distributed in the hope that it will be useful,              *
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of            *
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU         *
 *  Lesser General Public License for more details.                           *
 *                                                                            *
 *  You should have received a copy of the GNU Lesser General Public          *
 *  License along with this code; if not, write to the Free Software          *
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA *
 *                                                                            *
 *  iTunes and iPod are trademarks of Apple                                   *
 *                                                                            *
 *  This product is not supported/written/published by Apple!                 *
 *****************************************************************************/

#ifndef IPODDEVICEDETAILS_H
#define IPODDEVICEDETAILS_H

#include <qstring.h>
#include <qstringlist.h>
#include <qfile.h>

/**
 * Class encapsulating the DeviceDetails (name, owner, comment).
 * @author Andrew de Quincey
 */
class IPodDeviceDetails {
public:
    IPodDeviceDetails(const QString& filename);
    ~IPodDeviceDetails();
    bool load();
    bool save();
    void clear();

    /**
     * Accessor for name property.
     *
     * @return The value.
     */
    const QString& getName() const;

    /**
     * Accessor for owner property.
     *
     * @return The name.
     */
    const QString& getOwner() const;

    /**
     * Accessor for comment property.
     *
     * @return The comment.
     */
    const QString& getComment() const;

    /**
     * Setter for name property.
     *
     * @param name The value.
     */
    void setName(const QString& name);

    /**
     * Setter for owner property.
     *
     * @param owner The name of the owner.
     */
    void setOwner(const QString& owner);

    /**
     * Setter for comment property.
     *
     * @param comment The comment.
     */
    void setComment(const QString& comment);

private:
    // QString readDeviceInfoString(QFile& file, int position);
    QStringList readDeviceInfos( QFile& file );
    QString filename;

    QString name;
    QString owner;
    QString comment;

    bool dirty;
};

#endif
