 /*****************************************************************************
 *   Copyright (C) 2004 by Michael Schulze                                    *
 *   mike.s@genion.de                                                         *
 *                                                                            *
 *  The code contained in this file is free software; you can redistribute    *
 *  it and/or modify it under the terms of the GNU Lesser General Public      *
 *  License as published by the Free Software Foundation; either version      *
 *  2.1 of the License, or (at your option) any later version.                *
 *                                                                            *
 *  This file is distributed in the hope that it will be useful,              *
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of            *
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU         *
 *  Lesser General Public License for more details.                           *
 *                                                                            *
 *  You should have received a copy of the GNU Lesser General Public          *
 *  License along with this code; if not, write to the Free Software          *
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA *
 *                                                                            *
 *  iTunes and iPod are trademarks of Apple                                   *
 *                                                                            *
 *  This product is not supported/written/published by Apple!                 *
 *****************************************************************************/

#ifndef IPODMOUNTPOINT_H
#define IPODMOUNTPOINT_H

#include <qstring.h>
#include <vector>

/**
Parses /proc/mounts and looks for mounted iPods

@author Michael Schulze
*/
class IPodMountPoint{
public:
    typedef std::vector<IPodMountPoint> List;
    typedef std::vector<QString> StringVector;

    IPodMountPoint() {}
    IPodMountPoint( const StringVector& entry );
    ~IPodMountPoint();

    /**
     * Returns the device name found. In most cases this will be something like
     * /dev/...
     */
    const QString& getDevice() const;

    /**
     * Returns the path the device is mounted at
     */
    const QString& getMountPoint() const;

    /**
     * Returns the filesystem type name.
     */
    const QString& getFsType() const;

    /**
     * Returns the mount options.
     */
    const QString& getOptions() const;

    /**
     * Returns a List of mounted devices currently found in the system.
     */
    static List mountedIPods();

private:

    const QString& getField(uint fieldnum) const;

    std::vector<QString> fields;
};

#endif
