 /*****************************************************************************
 *   Copyright (C) 2004 by Michael Schulze                                    *
 *   mike.s@genion.de                                                         *
 *                                                                            *
 *  The code contained in this file is free software; you can redistribute    *
 *  it and/or modify it under the terms of the GNU Lesser General Public      *
 *  License as published by the Free Software Foundation; either version      *
 *  2.1 of the License, or (at your option) any later version.                *
 *                                                                            *
 *  This file is distributed in the hope that it will be useful,              *
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of            *
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU         *
 *  Lesser General Public License for more details.                           *
 *                                                                            *
 *  You should have received a copy of the GNU Lesser General Public          *
 *  License along with this code; if not, write to the Free Software          *
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA *
 *                                                                            *
 *  iTunes and iPod are trademarks of Apple                                   *
 *                                                                            *
 *  This product is not supported/written/published by Apple!                 *
 *****************************************************************************/

#ifndef ITUNESDBPLAYLISTITEM_H
#define ITUNESDBPLAYLISTITEM_H

#include "listitem.h"
#include "utils.h"

#define PLAYLISTITEM_INVALID 0xEEEEEEEE

namespace itunesdb {

/**
@author Michael Schulze
*/
class PlaylistItem : public ListItem
{
    friend class ItunesDBParser;
    friend class Playlist;

public:

    virtual ~PlaylistItem();

    /**
     * Returns the ID of the track this PlaylistItem is referring to.
     * @return the trackID of the track.
     */
    Q_UINT32 getID() const;

    /**
     * Returns the position in the playlist.
     */
    Q_UINT32 getPosition() const;

    /**
     * Sets the position of this PlaylistItem in the playlist.
     */
    void setPosition( Q_UINT32 pos );

    /**
     * Returns true if the position has been set.
     */
    bool isPositionSet() const { return m_pos != PLAYLISTITEM_INVALID; }

protected:

    PlaylistItem();
    PlaylistItem( Q_UINT32 ipod_id);

    /**
     * override from ListItem::doneAddingData()
     */
    virtual void doneAddingData();

    /**
     * Reads the playlist order MHODs
     */
    virtual void readMHOD( QDataStream& stream, Q_UINT32 type, Q_UINT32 blocklen );

    Q_UINT32 m_id;
    Q_UINT32 m_pos;
};

/**
 * This class compares two PlaylistItems and returns a negative int, zero, or
 * a positive int if the first item is smaller, equal or greater than the second.
 */
class PlaylistItemComparator : public itunesdb::utils::Comparator<PlaylistItem> {
public:
    virtual ~PlaylistItemComparator() {}
    virtual int compare( const PlaylistItem& item1, const PlaylistItem& item2 ) const = 0;
};

}

#endif
